summaryrefslogtreecommitdiffstats
path: root/Mac/Include/macglue.h
diff options
context:
space:
mode:
authorGuido van Rossum <guido@python.org>1995-01-18 23:57:26 (GMT)
committerGuido van Rossum <guido@python.org>1995-01-18 23:57:26 (GMT)
commit8f69179f973b1eb4c29914d73a275a2488132a08 (patch)
tree7c2e6868abaac2ff8e516ebc58446f0102389224 /Mac/Include/macglue.h
parent8d6c180c8d32d5c3126a1d9a30512cdb69343c64 (diff)
downloadcpython-8f69179f973b1eb4c29914d73a275a2488132a08.zip
cpython-8f69179f973b1eb4c29914d73a275a2488132a08.tar.gz
cpython-8f69179f973b1eb4c29914d73a275a2488132a08.tar.bz2
modernized/rationalized, added PyMac_BuildOSType
Diffstat (limited to 'Mac/Include/macglue.h')
-rw-r--r--Mac/Include/macglue.h18
1 files changed, 11 insertions, 7 deletions
diff --git a/Mac/Include/macglue.h b/Mac/Include/macglue.h
index 7c074d3..89d10d1 100644
--- a/Mac/Include/macglue.h
+++ b/Mac/Include/macglue.h
@@ -2,11 +2,15 @@
#include <Types.h>
#include <Resources.h>
-char *macstrerror PROTO((int)); /* strerror with mac errors */
-object *PyErr_Mac PROTO((object *, int)); /* Exception with a mac error */
-int PyMac_Idle PROTO((void)); /* Idle routine */
-int GetOSType PROTO((object *, ResType *)); /* argument parser for OSType */
-int GetStr255 PROTO((object *, Str255)); /* argument parser for Str255 */
-int GetFSSpec PROTO((object *, FSSpec *)); /* argument parser for FSSpec */
-object *PyMac_BuildFSSpec PROTO((FSSpec *)); /* Convert FSSpec to python object */
+char *macstrerror Py_PROTO((int)); /* strerror with mac errors */
+PyObject *PyErr_Mac Py_PROTO((PyObject *, int)); /* Exception with a mac error */
+int PyMac_Idle Py_PROTO((void)); /* Idle routine */
+int PyMac_GetOSType Py_PROTO((PyObject *, ResType *)); /* argument parser for OSType */
+int PyMac_GetStr255 Py_PROTO((PyObject *, Str255)); /* argument parser for Str255 */
+int PyMac_GetFSSpec Py_PROTO((PyObject *, FSSpec *)); /* argument parser for FSSpec */
+PyObject *PyMac_BuildFSSpec Py_PROTO((FSSpec *)); /* Convert FSSpec to PyObject */
+PyObject *PyMac_BuildOSType Py_PROTO((OSType)); /* Convert OSType to PyObject */
+#define GetOSType PyMac_GetOSType
+#define GetStr255 PyMac_GetStr255
+#define GetFSSpec PyMac_GetFSSpec